@@ -74,7 +74,7 @@ void AuthZoneCache::clear()
   purgeLockedCollectionsVector(d_maps);
 }
 
-void AuthZoneCache::replace(const vector<tuple<DNSName, int>>& zone_indices)
+void AuthZoneCache::replace(const vector<std::tuple<DNSName, int>>& zone_indices)
 {
   if (!d_refreshinterval)
     return;
@@ -83,10 +83,10 @@ void AuthZoneCache::replace(const vector<tuple<DNSName, int>>& zone_indices)
   vector<cmap_t> newMaps(d_maps.size());
 
   // build new maps
-  for (const tuple<DNSName, int>& tup : zone_indices) {
-    const DNSName& zone = tup.get<0>();
+  for (const std::tuple<DNSName, int>& tup : zone_indices) {
+    const DNSName& zone = std::get<0>(tup);
     CacheValue val;
-    val.zoneId = tup.get<1>();
+    val.zoneId = std::get<1>(tup);
     auto& mc = newMaps[getMapIndex(zone)];
     auto iter = mc.find(zone);
     if (iter != mc.end()) {
@@ -101,11 +101,11 @@ void AuthZoneCache::replace(const vector<tuple<DNSName, int>>& zone_indices)
     // process zone updates done while data collection for replace() was already in progress.
     auto pending = d_pending.lock();
     assert(pending->d_replacePending); // make sure we never forget to call setReplacePending()
-    for (const tuple<DNSName, int, bool>& tup : pending->d_pendingUpdates) {
-      const DNSName& zone = tup.get<0>();
+    for (const std::tuple<DNSName, int, bool>& tup : pending->d_pendingUpdates) {
+      const DNSName& zone = std::get<0>(tup);
       CacheValue val;
-      val.zoneId = tup.get<1>();
-      bool insert = tup.get<2>();
+      val.zoneId = std::get<1>(tup);
+      bool insert = std::get<2>(tup);
       auto& mc = newMaps[getMapIndex(zone)];
       auto iter = mc.find(zone);
       if (iter != mc.end()) {
